==> ragnutools-0.0.1.tar.gz: ragnutools-0.0.1/src/arp/rarpdeny.c <==
/* -*- Mode:C; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella <vasta@ragnu.it>
 */
 
#include <lupin/lupin.h>
#include <signal.h>
#include <stdlib.h>
#include <unistd.h>

/*struct deny*/
void *sdeny;

void usage()
{
	l_stderr("rarpdeny device ip_vict ip_deny\n");	
}

void end(l_int32 i)
{
	l_int32 ret;
	l_out out=l_arpdeny_close(&sdeny);
	if(l_isouterr(out))
	{
		l_printout(out);
		ret=EXIT_FAILURE;
	}
	else
	{	
		l_stdout("aprdeny routine finish\n");
		ret=EXIT_SUCCESS;
	}
	l_freeout(&out);
	exit(ret);
}

l_int32 main(l_int32 argc,l_char **argv)
{
	l_bool err=FALSE;
	if(argc !=4)
		err=TRUE;
	else
	{
		/*init function deny*/
		sdeny=l_arpdeny_init(argv[1],argv[2],argv[3]);
		/*signal*/
		signal(SIGINT,end);
		/*thread function*/
		l_arpdeny_exec(sdeny);
		end(0);
	}		
	if(err)
	{	
		usage();
		exit(EXIT_FAILURE);
	}
	exit(EXIT_SUCCESS);	
}

==> ragnutools-0.0.2.tar.gz: ragnutools-0.0.2/src/arp/rarpdeny.c <==
/* -*- Mode:C; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella <vasta@ragnu.it>
 */
 
#include <lupin/lupin.h>
#include <signal.h>
#include <unistd.h>
#include <stdlib.h>

/*struct deny*/
void *sdeny;

void usage()
{
	l_stderr("rarpdeny [macspoof]device ip_vict ip_deny\n");	
}

void end(l_int32 i)
{
	l_int32 ret;
	l_out out=l_arpdeny_close(&sdeny);
	if(l_isouterr(out))
	{
		l_printout(out);
		ret=EXIT_FAILURE;
	}
	else
	{	
		l_stdout("aprdeny routine finish\n");
		ret=EXIT_SUCCESS;
	}
	l_freeout(&out);
	exit(ret);
}

l_int32 main(l_int32 argc,l_char **argv)
{
	l_bool err=FALSE;
	l_int32 c;
	l_str macspoof=l_newstr();
	while ((c = getopt (argc, argv, "l:")) != -1)
	{
		switch(c)
		{
			case 'l': l_writestr(&macspoof,"%s",optarg);
				     argc-=2;
				     break;	
		}
	}
			
	if(argc !=4)
		err=TRUE;
	else
	{
		/*init function deny*/
		sdeny=l_arpdeny_init(argv[3],argv[4],argv[5],macspoof);
		l_freestr(&macspoof);	
		/*signal*/
		signal(SIGINT,end);
		/*thread function*/
		l_arpdeny_exec(sdeny);
		end(0);
	}		
	if(err)
	{	
		l_freestr(&macspoof);
		usage();
		exit(EXIT_FAILURE);
	}
	exit(EXIT_SUCCESS);	
}
